Documentation
¶
Overview ¶
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Index ¶
- type MockBuilder
- type MockBuilderMockRecorder
- type MockClient
- type MockClientMockRecorder
- type MockFactSummarizer
- type MockFactSummarizerMockRecorder
- type MockPromptManagerInterface
- type MockPromptManagerInterfaceMockRecorder
- type MockStore
- func (m *MockStore) Close() error
- func (m *MockStore) Delete(ctx context.Context, key string) error
- func (m *MockStore) EXPECT() *MockStoreMockRecorder
- func (m *MockStore) Exists(ctx context.Context, key string) (bool, error)
- func (m *MockStore) Get(ctx context.Context, key string) (string, error)
- func (m *MockStore) HDel(ctx context.Context, key, field string) error
- func (m *MockStore) HGet(ctx context.Context, key, field string) (string, error)
- func (m *MockStore) HGetAll(ctx context.Context, key string) (map[string]string, error)
- func (m *MockStore) HSet(ctx context.Context, key, field, value string) error
- func (m *MockStore) LPush(ctx context.Context, key, value string) error
- func (m *MockStore) LRange(ctx context.Context, key string, start, stop int64) ([]string, error)
- func (m *MockStore) Set(ctx context.Context, key, value string, expiration time.Duration) error
- func (m *MockStore) Type() string
- type MockStoreMockRecorder
- func (mr *MockStoreMockRecorder) Close() *gomock.Call
- func (mr *MockStoreMockRecorder) Delete(ctx, key any) *gomock.Call
- func (mr *MockStoreMockRecorder) Exists(ctx, key any) *gomock.Call
- func (mr *MockStoreMockRecorder) Get(ctx, key any) *gomock.Call
- func (mr *MockStoreMockRecorder) HDel(ctx, key, field any) *gomock.Call
- func (mr *MockStoreMockRecorder) HGet(ctx, key, field any) *gomock.Call
- func (mr *MockStoreMockRecorder) HGetAll(ctx, key any) *gomock.Call
- func (mr *MockStoreMockRecorder) HSet(ctx, key, field, value any) *gomock.Call
- func (mr *MockStoreMockRecorder) LPush(ctx, key, value any) *gomock.Call
- func (mr *MockStoreMockRecorder) LRange(ctx, key, start, stop any) *gomock.Call
- func (mr *MockStoreMockRecorder) Set(ctx, key, value, expiration any) *gomock.Call
- func (mr *MockStoreMockRecorder) Type() *gomock.Call
- type MockUserMemory
- func (m *MockUserMemory) DeleteFact(userID, key string) error
- func (m *MockUserMemory) EXPECT() *MockUserMemoryMockRecorder
- func (m *MockUserMemory) GetFact(userID, key string) (string, error)
- func (m *MockUserMemory) ListFacts(userID string) (map[string]string, error)
- func (m *MockUserMemory) SetFact(userID, key, value string) error
- type MockUserMemoryMockRecorder
- func (mr *MockUserMemoryMockRecorder) DeleteFact(userID, key any) *gomock.Call
- func (mr *MockUserMemoryMockRecorder) GetFact(userID, key any) *gomock.Call
- func (mr *MockUserMemoryMockRecorder) ListFacts(userID any) *gomock.Call
- func (mr *MockUserMemoryMockRecorder) SetFact(userID, key, value any) *gomock.Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockBuilder ¶
type MockBuilder struct {
// contains filtered or unexported fields
}
MockBuilder is a mock of Builder interface.
func NewMockBuilder ¶
func NewMockBuilder(ctrl *gomock.Controller) *MockBuilder
NewMockBuilder creates a new mock instance.
func (*MockBuilder) BuildPrompt ¶
func (m *MockBuilder) BuildPrompt(ctx context.Context, sessionID, userID, currentInput string, messageLimit int, summarizerFunction types.SummarizerFunction) ([]models.Message, error)
BuildPrompt mocks base method.
func (*MockBuilder) EXPECT ¶
func (m *MockBuilder) EXPECT() *MockBuilderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockBuilderMockRecorder ¶
type MockBuilderMockRecorder struct {
// contains filtered or unexported fields
}
MockBuilderMockRecorder is the mock recorder for MockBuilder.
func (*MockBuilderMockRecorder) BuildPrompt ¶
func (mr *MockBuilderMockRecorder) BuildPrompt(ctx, sessionID, userID, currentInput, messageLimit, summarizerFunction any) *gomock.Call
BuildPrompt indicates an expected call of BuildPrompt.
type MockClient ¶
type MockClient struct {
// contains filtered or unexported fields
}
MockClient is a mock of Client interface.
func NewMockClient ¶
func NewMockClient(ctrl *gomock.Controller) *MockClient
NewMockClient creates a new mock instance.
func (*MockClient) EXPECT ¶
func (m *MockClient) EXPECT() *MockClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockClient) StreamChat ¶
func (m *MockClient) StreamChat(ctx context.Context, messages []models.Message) (io.ReadCloser, error)
StreamChat mocks base method.
type MockClientMockRecorder ¶
type MockClientMockRecorder struct {
// contains filtered or unexported fields
}
MockClientMockRecorder is the mock recorder for MockClient.
func (*MockClientMockRecorder) Chat ¶
func (mr *MockClientMockRecorder) Chat(ctx, messages any) *gomock.Call
Chat indicates an expected call of Chat.
func (*MockClientMockRecorder) Name ¶
func (mr *MockClientMockRecorder) Name() *gomock.Call
Name indicates an expected call of Name.
func (*MockClientMockRecorder) StreamChat ¶
func (mr *MockClientMockRecorder) StreamChat(ctx, messages any) *gomock.Call
StreamChat indicates an expected call of StreamChat.
type MockFactSummarizer ¶
type MockFactSummarizer struct {
// contains filtered or unexported fields
}
MockFactSummarizer is a mock of FactSummarizer interface.
func NewMockFactSummarizer ¶
func NewMockFactSummarizer(ctrl *gomock.Controller) *MockFactSummarizer
NewMockFactSummarizer creates a new mock instance.
func (*MockFactSummarizer) EXPECT ¶
func (m *MockFactSummarizer) EXPECT() *MockFactSummarizerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockFactSummarizer) Summarizer ¶
func (m *MockFactSummarizer) Summarizer(ctx context.Context, facts map[string]string) (string, error)
Summarizer mocks base method.
type MockFactSummarizerMockRecorder ¶
type MockFactSummarizerMockRecorder struct {
// contains filtered or unexported fields
}
MockFactSummarizerMockRecorder is the mock recorder for MockFactSummarizer.
func (*MockFactSummarizerMockRecorder) Summarizer ¶
func (mr *MockFactSummarizerMockRecorder) Summarizer(ctx, facts any) *gomock.Call
Summarizer indicates an expected call of Summarizer.
type MockPromptManagerInterface ¶
type MockPromptManagerInterface struct {
// contains filtered or unexported fields
}
MockPromptManagerInterface is a mock of PromptManagerInterface interface.
func NewMockPromptManagerInterface ¶
func NewMockPromptManagerInterface(ctrl *gomock.Controller) *MockPromptManagerInterface
NewMockPromptManagerInterface creates a new mock instance.
func (*MockPromptManagerInterface) EXPECT ¶
func (m *MockPromptManagerInterface) EXPECT() *MockPromptManagerInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockPromptManagerInterface) Reload ¶
func (m *MockPromptManagerInterface) Reload() error
Reload mocks base method.
type MockPromptManagerInterfaceMockRecorder ¶
type MockPromptManagerInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockPromptManagerInterfaceMockRecorder is the mock recorder for MockPromptManagerInterface.
func (*MockPromptManagerInterfaceMockRecorder) Reload ¶
func (mr *MockPromptManagerInterfaceMockRecorder) Reload() *gomock.Call
Reload indicates an expected call of Reload.
type MockStore ¶
type MockStore struct {
// contains filtered or unexported fields
}
MockStore is a mock of Store interface.
func NewMockStore ¶
func NewMockStore(ctrl *gomock.Controller) *MockStore
NewMockStore creates a new mock instance.
func (*MockStore) EXPECT ¶
func (m *MockStore) EXPECT() *MockStoreMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockStoreMockRecorder ¶
type MockStoreMockRecorder struct {
// contains filtered or unexported fields
}
MockStoreMockRecorder is the mock recorder for MockStore.
func (*MockStoreMockRecorder) Close ¶
func (mr *MockStoreMockRecorder) Close() *gomock.Call
Close indicates an expected call of Close.
func (*MockStoreMockRecorder) Delete ¶
func (mr *MockStoreMockRecorder) Delete(ctx, key any) *gomock.Call
Delete indicates an expected call of Delete.
func (*MockStoreMockRecorder) Exists ¶
func (mr *MockStoreMockRecorder) Exists(ctx, key any) *gomock.Call
Exists indicates an expected call of Exists.
func (*MockStoreMockRecorder) Get ¶
func (mr *MockStoreMockRecorder) Get(ctx, key any) *gomock.Call
Get indicates an expected call of Get.
func (*MockStoreMockRecorder) HDel ¶
func (mr *MockStoreMockRecorder) HDel(ctx, key, field any) *gomock.Call
HDel indicates an expected call of HDel.
func (*MockStoreMockRecorder) HGet ¶
func (mr *MockStoreMockRecorder) HGet(ctx, key, field any) *gomock.Call
HGet indicates an expected call of HGet.
func (*MockStoreMockRecorder) HGetAll ¶
func (mr *MockStoreMockRecorder) HGetAll(ctx, key any) *gomock.Call
HGetAll indicates an expected call of HGetAll.
func (*MockStoreMockRecorder) HSet ¶
func (mr *MockStoreMockRecorder) HSet(ctx, key, field, value any) *gomock.Call
HSet indicates an expected call of HSet.
func (*MockStoreMockRecorder) LPush ¶
func (mr *MockStoreMockRecorder) LPush(ctx, key, value any) *gomock.Call
LPush indicates an expected call of LPush.
func (*MockStoreMockRecorder) LRange ¶
func (mr *MockStoreMockRecorder) LRange(ctx, key, start, stop any) *gomock.Call
LRange indicates an expected call of LRange.
func (*MockStoreMockRecorder) Set ¶
func (mr *MockStoreMockRecorder) Set(ctx, key, value, expiration any) *gomock.Call
Set indicates an expected call of Set.
func (*MockStoreMockRecorder) Type ¶
func (mr *MockStoreMockRecorder) Type() *gomock.Call
Type indicates an expected call of Type.
type MockUserMemory ¶
type MockUserMemory struct {
// contains filtered or unexported fields
}
MockUserMemory is a mock of UserMemory interface.
func NewMockUserMemory ¶
func NewMockUserMemory(ctrl *gomock.Controller) *MockUserMemory
NewMockUserMemory creates a new mock instance.
func (*MockUserMemory) DeleteFact ¶
func (m *MockUserMemory) DeleteFact(userID, key string) error
DeleteFact mocks base method.
func (*MockUserMemory) EXPECT ¶
func (m *MockUserMemory) EXPECT() *MockUserMemoryMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockUserMemory) GetFact ¶
func (m *MockUserMemory) GetFact(userID, key string) (string, error)
GetFact mocks base method.
func (*MockUserMemory) ListFacts ¶
func (m *MockUserMemory) ListFacts(userID string) (map[string]string, error)
ListFacts mocks base method.
func (*MockUserMemory) SetFact ¶
func (m *MockUserMemory) SetFact(userID, key, value string) error
SetFact mocks base method.
type MockUserMemoryMockRecorder ¶
type MockUserMemoryMockRecorder struct {
// contains filtered or unexported fields
}
MockUserMemoryMockRecorder is the mock recorder for MockUserMemory.
func (*MockUserMemoryMockRecorder) DeleteFact ¶
func (mr *MockUserMemoryMockRecorder) DeleteFact(userID, key any) *gomock.Call
DeleteFact indicates an expected call of DeleteFact.
func (*MockUserMemoryMockRecorder) GetFact ¶
func (mr *MockUserMemoryMockRecorder) GetFact(userID, key any) *gomock.Call
GetFact indicates an expected call of GetFact.